@@ -127,13 +127,16 @@ PointRenderer::SeriesStyle PointRenderer::getSeriesStyle(PointGroup *group)
 
     qsizetype index = group->colorIndex % seriesColors.size();
     QColor color = group->series->color().alpha() != 0 ? group->series->color() : seriesColors.at(index);
+    color.setAlpha(color.alpha() * group->series->opacity());
 
     QColor selectedColor = group->series->selectedColor().alpha() != 0
                                ? group->series->selectedColor()
                                : m_graph->theme()->singleHighlightColor();
+    selectedColor.setAlpha(selectedColor.alpha() * group->series->opacity());
 
     index = group->colorIndex % borderColors.size();
     QColor borderColor = borderColors.at(index);
+    borderColor.setAlpha(borderColor.alpha() * group->series->opacity());
     qreal borderWidth = theme->borderWidth();
 
     return {
@@ -447,7 +450,7 @@ void PointRenderer::handlePolish(QXYSeries *series)
                 group->shapePath->setPath(painterPath);
             }
 
-            for (auto m : group->markers)
+            for (auto m : std::as_const(group->markers))
                 m->deleteLater();
 
             group->markers.clear();
@@ -611,7 +614,7 @@ void PointRenderer::afterPolish(QList<QAbstractSeries *> &cleanupSeries)
         if (xySeries && m_groups.contains(xySeries)) {
             auto group = m_groups.value(xySeries);
 
-            for (auto marker : group->markers)
+            for (auto marker : std::as_const(group->markers))
                 marker->deleteLater();
 
             if (group->shapePath) {
