@@ -61,6 +61,7 @@ void tst_qgpieseries::properties()
     QSignalSpy countSpy(m_series, SIGNAL(countChanged()));
     QSignalSpy sumSpy(m_series, SIGNAL(sumChanged()));
     QSignalSpy opacitySpy(m_series, SIGNAL(opacityChanged()));
+    QSignalSpy valuesMultiplierSpy(m_series, SIGNAL(valuesMultiplierChanged()));
 
     QVERIFY(m_series->type() == QAbstractSeries::SeriesType::Pie);
     QVERIFY(m_series->count() == 0);
@@ -72,6 +73,7 @@ void tst_qgpieseries::properties()
     QCOMPARE(m_series->startAngle(), 0.0);
     QCOMPARE(m_series->endAngle(), 360.0);
     QCOMPARE(m_series->opacity(), 1.0);
+    QCOMPARE(m_series->valuesMultiplier(), 1.0);
 
     m_series->append("s1", 1);
     m_series->append("s2", 1);
@@ -103,11 +105,11 @@ void tst_qgpieseries::properties()
 
     m_series->setHoleSize(0.8);
     QCOMPARE(m_series->holeSize(), 0.8);
-    QCOMPARE(m_series->pieSize(), 0.8);
+    QCOMPARE(m_series->pieSize(), 0.7);
 
     m_series->setPieSize(0.4);
     QCOMPARE(m_series->pieSize(), 0.4);
-    QCOMPARE(m_series->holeSize(), 0.4);
+    QCOMPARE(m_series->holeSize(), 0.8);
 
     m_series->setStartAngle(0);
     m_series->setStartAngle(-180);
@@ -142,11 +144,18 @@ void tst_qgpieseries::properties()
     m_series->setOpacity(1.0);
     QCOMPARE(m_series->opacity(), 1.0);
     QCOMPARE(opacitySpy.size(), 3);
+
+    m_series->setValuesMultiplier(0.5);
+    QCOMPARE(m_series->valuesMultiplier(), 0.5);
+    QCOMPARE(valuesMultiplierSpy.size(), 1);
+    m_series->setValuesMultiplier(0);
+    QCOMPARE(m_series->valuesMultiplier(), 0);
+    QCOMPARE(valuesMultiplierSpy.size(), 2);
 }
 
 void tst_qgpieseries::append()
 {
-    QSignalSpy addedSpy(m_series, SIGNAL(added(QList<QPieSlice *>)));
+    QSignalSpy addedSpy(m_series, SIGNAL(added(QList<QPieSlice*>)));
 
     // append pointer
     QPieSlice *slice1 = 0;
@@ -211,7 +220,7 @@ void tst_qgpieseries::append()
 
 void tst_qgpieseries::insert()
 {
-    QSignalSpy addedSpy(m_series, SIGNAL(added(QList<QPieSlice *>)));
+    QSignalSpy addedSpy(m_series, SIGNAL(added(QList<QPieSlice*>)));
 
     // insert one slice
     QPieSlice *slice1 = 0;
@@ -262,7 +271,7 @@ void tst_qgpieseries::insert()
 
 void tst_qgpieseries::remove()
 {
-    QSignalSpy removedSpy(m_series, SIGNAL(removed(QList<QPieSlice *>)));
+    QSignalSpy removedSpy(m_series, SIGNAL(removed(QList<QPieSlice*>)));
 
     // add some slices
     QPieSlice *slice1 = m_series->append("slice 1", 1);
@@ -327,8 +336,8 @@ void tst_qgpieseries::replace()
 {
     QVERIFY(m_series);
 
-    QSignalSpy removedSpy(m_series, SIGNAL(removed(QList<QPieSlice *>)));
-    QSignalSpy replacedSpy(m_series, SIGNAL(replaced(QList<QPieSlice *>)));
+    QSignalSpy removedSpy(m_series, SIGNAL(removed(QList<QPieSlice*>)));
+    QSignalSpy replacedSpy(m_series, SIGNAL(replaced(QList<QPieSlice*>)));
 
     QPieSeries series2;
     auto slice1 = new QPieSlice("slice 1", 1);
@@ -425,7 +434,7 @@ void tst_qgpieseries::replace()
 
 void tst_qgpieseries::take()
 {
-    QSignalSpy removedSpy(m_series, SIGNAL(removed(QList<QPieSlice *>)));
+    QSignalSpy removedSpy(m_series, SIGNAL(removed(QList<QPieSlice*>)));
 
     // add some slices
     QPieSlice *slice1 = m_series->append("slice 1", 1);
