@@ -65,6 +65,8 @@ void tst_axis::initialProperties()
     QCOMPARE(m_axis->title(), QString(""));
     QCOMPARE(m_axis->isTitleFixed(), true);
     QCOMPARE(m_axis->isTitleVisible(), false);
+    QCOMPARE(m_axis->isScaleLabelsByCount(), false);
+    QCOMPARE(m_axis->labelSize(), 1.0f);
     QCOMPARE(m_axis->type(), QAbstract3DAxis::AxisType::Category);
 }
 
@@ -72,10 +74,25 @@ void tst_axis::initializeProperties()
 {
     QVERIFY(m_axis);
 
+    QSignalSpy labelSpy(m_axis, &QCategory3DAxis::labelsChanged);
+    QSignalSpy rowLabelSpy(m_axis, &QCategory3DAxis::rowLabelsChanged);
+    QSignalSpy columnLabelSpy(m_axis, &QCategory3DAxis::columnLabelsChanged);
+
+    QSignalSpy autoAdjustSpy(m_axis, &QCategory3DAxis::autoAdjustRangeChanged);
+    QSignalSpy labelAutoAngleSpy(m_axis, &QCategory3DAxis::labelAutoAngleChanged);
+    QSignalSpy maxSpy(m_axis, &QCategory3DAxis::maxChanged);
+    QSignalSpy minSpy(m_axis, &QCategory3DAxis::minChanged);
+    QSignalSpy titleSpy(m_axis, &QCategory3DAxis::titleChanged);
+    QSignalSpy titleFixedSpy(m_axis, &QCategory3DAxis::titleFixedChanged);
+    QSignalSpy titleVisibleSpy(m_axis, &QCategory3DAxis::titleVisibleChanged);
+
     m_axis->setLabels(QStringList() << "first" << "second");
 
     QCOMPARE(m_axis->labels().size(), 2);
     QCOMPARE(m_axis->labels().at(1), QString("second"));
+    QCOMPARE(labelSpy.size(), 1);
+    QCOMPARE(rowLabelSpy.size(), 0);
+    QCOMPARE(columnLabelSpy.size(), 0);
 
     // Common (from QAbstract3DAxis)
     m_axis->setAutoAdjustRange(false);
@@ -85,6 +102,8 @@ void tst_axis::initializeProperties()
     m_axis->setTitle("title");
     m_axis->setTitleFixed(false);
     m_axis->setTitleVisible(true);
+    m_axis->setScaleLabelsByCount(true);
+    m_axis->setLabelSize(2.0f);
 
     QCOMPARE(m_axis->isAutoAdjustRange(), false);
     QCOMPARE(m_axis->labelAutoAngle(), 15.0f);
@@ -93,6 +112,16 @@ void tst_axis::initializeProperties()
     QCOMPARE(m_axis->title(), QString("title"));
     QCOMPARE(m_axis->isTitleFixed(), false);
     QCOMPARE(m_axis->isTitleVisible(), true);
+    QCOMPARE(m_axis->isScaleLabelsByCount(), true);
+    QCOMPARE(m_axis->labelSize(), 2.0f);
+
+    QCOMPARE(autoAdjustSpy.size(), 1);
+    QCOMPARE(labelAutoAngleSpy.size(), 1);
+    QCOMPARE(maxSpy.size(), 1);
+    QCOMPARE(minSpy.size(), 1);
+    QCOMPARE(titleSpy.size(), 1);
+    QCOMPARE(titleFixedSpy.size(), 1);
+    QCOMPARE(titleVisibleSpy.size(), 1);
 }
 
 void tst_axis::invalidProperties()
